@@ -195,7 +195,8 @@ cal_fill_event_list_ui(CalHomePlugin* desktop_plugin)
 				      GTK_RC_FG,
 				      GTK_STATE_NORMAL,
 				      "ActiveTextColor");
-      GtkWidget* summary_label = gtk_label_new(summary);
+      GtkWidget* summary_label = gtk_label_new(NULL);
+      gtk_label_set_markup(GTK_LABEL(summary_label), summary);
       hildon_helper_set_logical_font(summary_label,
 				     "HomeSystemFont");
       hildon_helper_set_logical_color(summary_label,
@@ -249,17 +250,19 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
 					   gsize up_to)
 {
   struct tm end_date;
-  struct tm end_date_x;
+  struct tm end_date_today;
   cal_home_time_today_now(&end_date);
-  cal_home_time_today_midnight(&end_date_x);
-  end_date_x.tm_mday++;
-  time_t end_time_x = mktime(&end_date_x);
+  cal_home_time_today_midnight(&end_date_today);
+  end_date_today.tm_mday++;
+  int earliest_update_end_time = mktime(&end_date_today);
+  time_t end_time_today = mktime(&end_date_today);
   time_t end_time = cal_home_advance_date_by_time_period(&end_date,
 							 desktop_plugin->cal_time_period);
   time_t date_today_time = mktime(&desktop_plugin->date_today);
-  GtkTreeIter iter;
-  int earliest_update_end_time = end_time_x;
+  time_t system_time_offset = CMulticalendar::MCInstance()->getSystemTimeShift();
+
   desktop_plugin->today_events = 0;
+  GtkTreeIter iter;
   for(SortedCComponentSet::const_iterator event_iter = ccomponent_set.begin();
       event_iter != ccomponent_set.end() && up_to>0;
       ++event_iter)
@@ -267,24 +270,32 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
     gtk_list_store_append(list_store,
 			  &iter);
     string summary = (*event_iter)->getSummary();
-    string component = (*event_iter)->toString();
-    time_t start = (*event_iter)->getDateStart();
-    time_t end_time = (*event_iter)->getDateEnd();
-
-    struct tm* time = localtime(&start);
+    if((*event_iter)->getType() == E_TODO)
+    {
+      if((*event_iter)->getStatus() == 1)
+      {
+	summary = "<s>"+ summary + "</s>";
+      }
+    }
+    time_t event_start_time = (*event_iter)->getDateStart();
+    time_t event_end_time = (*event_iter)->getDateEnd();
+    time_t event_time_offset = (*event_iter)->getTzOffset();
+    struct tm* time = localtime(&event_start_time);
+    event_end_time += event_time_offset - system_time_offset;
+    event_start_time += event_time_offset - system_time_offset;
     char buf[255];
-    if(cal_date_on_today((*event_iter)->getDateStart(), desktop_plugin) || 
-       start < date_today_time)
+    if(cal_date_on_today(event_start_time, desktop_plugin) || 
+       (event_start_time <= date_today_time && (event_end_time == -1 || event_end_time >= date_today_time)))
     {
       ++desktop_plugin->today_events;
-      
-      if(earliest_update_end_time>(*event_iter)->getDateEnd())
-	earliest_update_end_time = (*event_iter)->getDateEnd()+60;
-      if(date_today_time < (*event_iter)->getDateStart() &&
-	 earliest_update_end_time > (*event_iter)->getDateStart())
-	earliest_update_end_time = (*event_iter)->getDateStart()+60;
+      if(earliest_update_end_time>event_end_time)
+	earliest_update_end_time = end_time+60;
+      if(date_today_time < event_start_time &&
+	 earliest_update_end_time > event_start_time)
+	earliest_update_end_time = event_start_time+60;
 
-      if((*event_iter)->getAllDay() || (start <= date_today_time && end_time >= date_today_time))
+      if((*event_iter)->getAllDay() || (event_start_time <= date_today_time && 
+					end_time >= end_time_today))
       {      
 	gtk_list_store_set(list_store, &iter,
 			   0, dgettext("calendar", "cal_va_allday_home"),
@@ -292,7 +303,6 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
       }
       else
       {
-	
 	if(desktop_plugin->has_24_time_format)
 	  strftime(buf, 255,dgettext("hildon-libs","wdgt_va_24h_time"), time);
 	else
@@ -319,7 +329,7 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
 			 -1);
     }
     GdkPixbuf *pixbuf = get_calendar_pixbuf(*event_iter);
-
+    
     gtk_list_store_set(list_store, &iter,
 		       1, summary.c_str(), 
 		       2, pixbuf,
@@ -373,18 +383,25 @@ cal_read_ccompnents_for_calendar(CCalendar* calendar,
     size = calendars_components.size();
     offset+=limit;
     time_t last_start_date = start_time;
+    time_t system_time_offset = CMulticalendar::MCInstance()->getSystemTimeShift();
     for(int k = 0;k<calendars_components.size();++k)
     {
       CComponent* component = calendars_components[k];
+
+      time_t event_time_offset = component->getTzOffset();
+
       vector<time_t> instance_times =
 	component->getInstanceTimes(last_start_date, 
 				    end_time);
-      // Remove Task Components now
-      // others are cleaned up later
       if((desktop_plugin->visible_entry_mode == VISIBLE_ENTRY_EVENT && calendars_components[k]->getType() == E_TODO) ||
-	 (!birthday_only && calendars_components[k]->getType() == E_BDAY) ||
-	 (birthday_only && calendars_components[k]->getType() != E_BDAY) ||
-	 (desktop_plugin->visible_entry_mode == VISIBLE_ENTRY_TASK && calendars_components[k]->getType() != E_TODO)
+	 (FALSE==birthday_only && 
+	  ((calendars_components[k]->getType() == E_BDAY) ||
+	   (calendars_components[k]->getType() == E_TODO))) ||
+	 (birthday_only && (calendars_components[k]->getType() == E_EVENT)) ||
+	 (desktop_plugin->visible_entry_mode == VISIBLE_ENTRY_TASK && calendars_components[k]->getType() != E_TODO) ||
+	 (component->getType() == E_TODO && component->getDateStart() > end_time) ||
+	 (component->getType() == E_EVENT && ((component->getDateEnd() + (event_time_offset-system_time_offset))<
+	 start_time))
 	 )
       {
 	delete calendars_components[k];
@@ -401,8 +418,11 @@ cal_read_ccompnents_for_calendar(CCalendar* calendar,
 	  do
 	  {
 	    // clone entry with instance time as start time
+	    // and set end time 
 	    CComponent* c = new CComponent(*component);
+	    c->setDateEnd((*iter) + c->getDateEnd() - c->getDateStart());
 	    c->setDateStart(*iter);
+
 	    if(c->getType() == E_BDAY &&
 	       desktop_plugin->show_age)
 	    {
@@ -429,7 +449,6 @@ cal_read_ccomponents_all_visible(SortedCComponentSet& all_components,
   struct tm end_date = desktop_plugin->date_today;
   time_t end_time = cal_home_advance_date_by_time_period(&end_date,
 							 desktop_plugin->cal_time_period);
-
   struct tm today_midnight; 
   cal_home_time_today_midnight(&today_midnight);
   time_t today_midnight_time = mktime(&today_midnight);
