@@ -26,6 +26,8 @@
 #define CAL_HP_KEY_CAL_TIME_PERIOD "cal_time_period"
 #define CAL_HP_KEY_CAL_SHOW_AGE "cal_show_age"
 #define CAL_HP_KEY_CAL_UPDATE_IF_VISIBLE "update_if_visible"
+#define CAL_HP_KEY_CAL_SHOW_ALL_RECURRENCES "show_all_recurrences"
+#define CAL_HP_KEY_CAL_VISIBLE_ENTRY_MODE "visible_entry_mode"
 #define CAL_HOME_PLUGIN_SETTINGS_FILE "/.cal_home_widget"
 
 void 
@@ -83,7 +85,21 @@ cal_home_read_settings(CalHomePlugin *desktop_plugin)
 								 CAL_HP_KEY_CAL_UPDATE_IF_VISIBLE,
 								 NULL);
     }
-
+    if(g_key_file_has_key(keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_SHOW_ALL_RECURRENCES, NULL))
+    {
+      desktop_plugin->show_all_recurrences = g_key_file_get_boolean(keyFile, 
+								    desktop_plugin->iD, 
+								    CAL_HP_KEY_CAL_SHOW_ALL_RECURRENCES,
+								    NULL);
+    }
+    if(g_key_file_has_key(keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_VISIBLE_ENTRY_MODE, NULL))
+    {
+      desktop_plugin->visible_entry_mode = VisibleEntryMode(g_key_file_get_integer(keyFile, 
+										desktop_plugin->iD, 
+										CAL_HP_KEY_CAL_VISIBLE_ENTRY_MODE,
+										NULL));
+      
+    }
   }
   g_key_file_free(keyFile);
   g_free(fileName);
@@ -110,6 +126,8 @@ cal_home_save_settings(CalHomePlugin* desktop_plugin)
   g_key_file_set_integer (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_TIME_PERIOD, desktop_plugin->cal_time_period);
   g_key_file_set_boolean (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_SHOW_AGE, desktop_plugin->show_age);
   g_key_file_set_boolean (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_UPDATE_IF_VISIBLE, desktop_plugin->update_if_visible);
+  g_key_file_set_boolean (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_SHOW_ALL_RECURRENCES, desktop_plugin->show_all_recurrences);
+  g_key_file_set_integer (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_VISIBLE_ENTRY_MODE, desktop_plugin->visible_entry_mode);
 
   fileData = g_key_file_to_data (keyFile, &size, NULL);
   g_file_set_contents(filename, fileData, size, NULL);
