@@ -553,8 +553,9 @@ register_gconf_notify_on_timeformat_changed(CalHomePlugin* desktop_plugin)
   gconf_client_add_dir(client, GCONF_TIME_FORMAT_PATH,
 		       GCONF_CLIENT_PRELOAD_NONE,
 		       NULL);
-  guint handle_id = gconf_client_notify_add(client, GCONF_TIME_FORMAT_PATH,
-					    handle_time_format_changed, desktop_plugin, NULL, NULL);
+  desktop_plugin->gconf_notify_handler = gconf_client_notify_add(client, GCONF_TIME_FORMAT_PATH,
+								 handle_time_format_changed, 
+								 desktop_plugin, NULL, NULL);
   g_object_unref(client);
 }
 
